/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
#ifndef __COPYDISC_H__
#define __COPYDISC_H__

#include "aspi.h"
#include "cmd.h"

#define HID_VIRTUAL		100

typedef struct {
  int hid;
  int tid;
} DRIVEID;

#ifdef __cplusplus
extern "C" {
#endif

int CopyDisc(DRIVEID *reader, DRIVEID *writer, int num_writer);

#ifdef __cplusplus
}
#endif


#endif /* !__COPYDISC_H__ */
